'use strict';

var _userManager = require('../server/managers/userManager');

var _userManager2 = _interopRequireDefault(_userManager);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var _require = require('./Help'),
    Help = _require.Help;

var User = function User(args) {
  var _this = this;

  _classCallCheck(this, User);

  this.run = function () {
    if (!_this.args.length) {
      Help.displayUserCommandHelp();
    } else {
      runCommand(_this.args);
    }
  };

  this.args = args;
};

function runCommand(args) {
  switch (args[0]) {
    case '-list':
      return runListCommand(args);
    case '-add':
      return runAddCommand(args);
    case '-remove':
      return runRemoveCommand(args);
    case '-generateToken':
      return runGenerateTokenCommand(args);
    default:
      Help.displayUserCommandHelp();
  }
}

function runListCommand(args) {
  if (args.length > 1) return Help.displayExtraArgumentHelp(args[1]);

  try {
    _userManager2.default.list();
  } catch (e) {
    console.log(e);
  }
}

function runAddCommand(args) {
  if (args.length < 5) return Help.displayUserCommandHelp();
  if (args.length > 5) return Help.displayExtraArgumentHelp(args[5]);

  try {
    _userManager2.default.createUser(args[1], args[2], args[3], args[4]);
  } catch (e) {
    console.log(e);
  }
}

function runRemoveCommand(args) {
  if (args.length > 2) return Help.displayExtraArgumentHelp(args[2]);

  try {
    _userManager2.default.removeUser(args[1]);
  } catch (e) {
    console.log(e);
  }
}

function runGenerateTokenCommand(args) {
  if (args.length > 2) return Help.displayExtraArgumentHelp(args[2]);

  try {
    _userManager2.default.generateToken(args[1]);
  } catch (e) {
    console.log(e);
  }
}

exports.User = User;