'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _async = require('async');

var _async2 = _interopRequireDefault(_async);

var _baseApiController = require('./baseApiController');

var _baseApiController2 = _interopRequireDefault(_baseApiController);

var _elementInstanceService = require('../../services/elementInstanceService');

var _elementInstanceService2 = _interopRequireDefault(_elementInstanceService);

var _appUtils = require('../../utils/appUtils');

var _appUtils2 = _interopRequireDefault(_appUtils);

var _winstonLogs = require('../../utils/winstonLogs');

var _winstonLogs2 = _interopRequireDefault(_winstonLogs);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/********************************************* EndPoints ******************************************************/

/****** Instance Container Config EndPoint (Post: /api/v2/instance/containerconfig/id/:ID/token/:Token) *******/
var containerConfigEndPoint = function containerConfigEndPoint(req, res) {
	_winstonLogs2.default.info("Endpoint hit: " + req.originalUrl);
	var params = {},
	    instanceProps = {
		fogId: 'bodyParams.ID',
		setProperty: 'outputData'
	};

	params.bodyParams = req.params;
	_winstonLogs2.default.info("Parameters:" + JSON.stringify(params.bodyParams));

	_async2.default.waterfall([_async2.default.apply(_baseApiController2.default.checkUserExistance, req, res), _async2.default.apply(_elementInstanceService2.default.getElementInstancesByFogId, instanceProps, params), processOutput], function (err, result) {
		_appUtils2.default.sendResponse(res, err, 'containerconfig', params.containerList, result);
	});
};

/*********************************** Extra Functions ***************************************************/
/**
 * @file instanceContainerListController.js
 * @author Zishan Iqbal
 * @description This file includes the implementation of the instance-container-config end-point
 */

var processOutput = function processOutput(params, callback) {
	var containerList = new Array();
	for (var i = 0; i < params.outputData.length; i++) {
		var container = params.outputData[i],
		    containerId = container.uuid;

		if (container.isStreamViewer > 0) {
			containerId = "viewer";
		}
		if (container.isDebugConsole > 0) {
			containerId = "debug";
		}
		var containerUpdated = container.configLastUpdated,
		    containerConfig = container.config;
		containerList.push({
			'id': containerId,
			'lastupdatedtimestamp': containerUpdated,
			'config': containerConfig
		});
		params.containerList = containerList;
	}
	callback(null, params);
};

exports.default = {
	containerConfigEndPoint: containerConfigEndPoint
};