'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _async = require('async');

var _async2 = _interopRequireDefault(_async);

var _baseApiController = require('./baseApiController');

var _baseApiController2 = _interopRequireDefault(_baseApiController);

var _appUtils = require('../../utils/appUtils');

var _appUtils2 = _interopRequireDefault(_appUtils);

var _winstonLogs = require('../../utils/winstonLogs');

var _winstonLogs2 = _interopRequireDefault(_winstonLogs);

var _instanceResourcesService = require('../../services/instanceResourcesService');

var _instanceResourcesService2 = _interopRequireDefault(_instanceResourcesService);

var _userService = require('../../services/userService');

var _userService2 = _interopRequireDefault(_userService);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/********************************************* EndPoints ******************************************************/

/******************** Fog Instance HWInfo (Post: /api/v2/instance/hw_info/id/:ID/token/:Token) ******************/
/**
 * @author elukashick
 */

var fogInstanceHWInfo = function fogInstanceHWInfo(req, res) {
    _winstonLogs2.default.info("Endpoint hit: " + req.originalUrl);

    var params = {},
        fogHWInfo = {
        fogInfo: 'body.info',
        uuid: 'bodyParams.ID',
        setProperty: 'fogHWInfo'
    };

    params.body = req.body;
    params.bodyParams = req.params;
    _winstonLogs2.default.info("Parameters:" + JSON.stringify(params.bodyParams));

    _async2.default.waterfall([_async2.default.apply(_baseApiController2.default.checkUserExistance, req, res), _async2.default.apply(_instanceResourcesService2.default.saveHWInfo, fogHWInfo, params)], function (err, result) {
        var output = void 0;
        if (!err) {
            output = params.bodyParams.ID;
        }
        _appUtils2.default.sendResponse(res, err, 'uuid', output, result);
    });
};
/******************** Fog Instance USBInfo (Post: /api/v2/instance/usb_info/id/:ID/token/:Token) ******************/
var fogInstanceUSBInfo = function fogInstanceUSBInfo(req, res) {
    _winstonLogs2.default.info("Endpoint hit: " + req.originalUrl);

    var params = {},
        fogUSBInfo = {
        fogInfo: 'body.info',
        uuid: 'bodyParams.ID',
        setProperty: 'fogHWInfo'
    };

    params.body = req.body;
    params.bodyParams = req.params;
    _winstonLogs2.default.info("Parameters:" + JSON.stringify(params.bodyParams));

    _async2.default.waterfall([_async2.default.apply(_baseApiController2.default.checkUserExistance, req, res), _async2.default.apply(_instanceResourcesService2.default.saveUSBInfo, fogUSBInfo, params)], function (err, result) {
        var output = void 0;
        if (!err) {
            output = params.bodyParams.ID;
        }
        _appUtils2.default.sendResponse(res, err, 'uuid', output, result);
    });
};

/*********** POST getFogHwInfoEndPoint EndPoint (Post: /api/v2/authoring/fog/info/hw) **********/
var getFogHwInfoEndPoint = function getFogHwInfoEndPoint(req, res) {
    _winstonLogs2.default.info("Endpoint hit: " + req.originalUrl);

    var params = {},
        userProps = {
        userId: 'bodyParams.t',
        setProperty: 'user'
    },
        instanceProps = {
        instanceId: 'bodyParams.instanceId',
        setProperty: 'fogInstances'
    };

    params.bodyParams = req.body;
    _winstonLogs2.default.info("Parameters:" + JSON.stringify(params.bodyParams));

    _async2.default.waterfall([_async2.default.apply(_userService2.default.getUser, userProps, params), _async2.default.apply(_instanceResourcesService2.default.getFogHwInfo, instanceProps)], function (err, result) {
        _appUtils2.default.sendResponse(res, err, 'fog', params.fogInstances, result);
    });
};
/*********** POST getFogUsbInfoEndPoint EndPoint (Post: /api/v2/authoring/fog/info/usb) **********/
var getFogUsbInfoEndPoint = function getFogUsbInfoEndPoint(req, res) {
    _winstonLogs2.default.info("Endpoint hit: " + req.originalUrl);

    var params = {},
        userProps = {
        userId: 'bodyParams.t',
        setProperty: 'user'
    },
        instanceProps = {
        instanceId: 'bodyParams.instanceId',
        setProperty: 'fogInstances'
    };

    params.bodyParams = req.body;
    _winstonLogs2.default.info("Parameters:" + JSON.stringify(params.bodyParams));

    _async2.default.waterfall([_async2.default.apply(_userService2.default.getUser, userProps, params), _async2.default.apply(_instanceResourcesService2.default.getFogUsbInfo, instanceProps)], function (err, result) {
        _appUtils2.default.sendResponse(res, err, 'fog', params.fogInstances, result);
    });
};

exports.default = {
    fogInstanceHWInfo: fogInstanceHWInfo,
    fogInstanceUSBInfo: fogInstanceUSBInfo,
    getFogHwInfoEndPoint: getFogHwInfoEndPoint,
    getFogUsbInfoEndPoint: getFogUsbInfoEndPoint
};