'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _async = require('async');

var _async2 = _interopRequireDefault(_async);

var _consoleService = require('../../services/consoleService');

var _consoleService2 = _interopRequireDefault(_consoleService);

var _streamViewerService = require('../../services/streamViewerService');

var _streamViewerService2 = _interopRequireDefault(_streamViewerService);

var _userService = require('../../services/userService');

var _userService2 = _interopRequireDefault(_userService);

var _appUtils = require('../../utils/appUtils');

var _appUtils2 = _interopRequireDefault(_appUtils);

var _winstonLogs = require('../../utils/winstonLogs');

var _winstonLogs2 = _interopRequireDefault(_winstonLogs);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/********************************************* EndPoints ******************************************************/

/******************** Fog Viewer Access EndPoint (Get: /api/v2/authoring/fabric/viewer/access) ***************/
/**
 * @file streamViewerController.js
 * @author Zishan Iqbal
 * @description This file includes the implementation of the StreamViewer related endpoints
 */

var fogViewerAccessEndPoint = function fogViewerAccessEndPoint(req, res) {
  _winstonLogs2.default.info("Endpoint hit: " + req.originalUrl);
  var params = {},
      userProps = {
    userId: 'bodyParams.t',
    setProperty: 'user'
  },
      streamViewerProps = {
    instanceId: 'bodyParams.instanceId',
    setProperty: 'streamViewer'
  },
      consoleProps = {
    instanceId: 'bodyParams.instanceId',
    setProperty: 'console'
  };
  params.bodyParams = req.query;
  _winstonLogs2.default.info("Parameters:" + JSON.stringify(params.bodyParams));

  _async2.default.waterfall([_async2.default.apply(_userService2.default.getUser, userProps, params), _async2.default.apply(_streamViewerService2.default.getStreamViewerByFogInstanceId, streamViewerProps), _async2.default.apply(_consoleService2.default.getConsoleByFogInstanceId, consoleProps), getResponse], function (err, result) {
    var errMsg = 'Internal error: There was a problem getting the toolset access for this ioFog instance.' + result;
    _appUtils2.default.sendResponse(res, err, 'access', result.output, errMsg);
  });
};

/************************************* Extra Functions **************************************************/
var getResponse = function getResponse(params, callback) {
  var output = {};

  if (params.streamViewer) {
    output.streamViewerUrl = params.streamViewer.apiBaseUrl;
    output.streamViewerToken = params.streamViewer.accessToken;
  }

  if (params.console) {
    output.consoleUrl = params.console.apiBaseUrl;
    output.consoleToken = params.console.accessToken;
  }

  callback(null, {
    'output': output
  });
};

exports.default = {
  fogViewerAccessEndPoint: fogViewerAccessEndPoint
};