'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _sequelize = require('sequelize');

var _sequelize2 = _interopRequireDefault(_sequelize);

var _sequelize3 = require('./../utils/sequelize');

var _sequelize4 = _interopRequireDefault(_sequelize3);

var _fog = require('./fog');

var _fog2 = _interopRequireDefault(_fog);

var _elementInstance = require('./elementInstance');

var _elementInstance2 = _interopRequireDefault(_elementInstance);

var _elementInstancePort = require('./elementInstancePort');

var _elementInstancePort2 = _interopRequireDefault(_elementInstancePort);

var _satellitePort = require('./satellitePort');

var _satellitePort2 = _interopRequireDefault(_satellitePort);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * @file networkPairing.js
 * @author Zishan Iqbal
 * @description This file includes a networkPairing model used by sequalize for ORM;
 */

var NetworkPairing = _sequelize4.default.define('network_pairing', {
  id: {
    type: _sequelize2.default.INTEGER,
    primaryKey: true,
    autoIncrement: true,
    field: 'ID'
  },
  isPublicPort: {
    type: _sequelize2.default.BOOLEAN,
    field: 'IsPublicPort'
  }
}, {
  // don't add the timestamp attributes (updatedAt, createdAt)
  timestamps: false,
  // disable the modification of table names
  freezeTableName: true,
  // don't use camelcase for automatically added attributes but underscore style
  // so updatedAt will be updated_at
  underscored: true
});

NetworkPairing.belongsTo(_fog2.default, {
  foreignKey: 'instanceId1',
  as: 'InstanceId1'
});
NetworkPairing.belongsTo(_fog2.default, {
  foreignKey: 'instanceId2',
  as: 'InstanceId2'
});
NetworkPairing.belongsTo(_elementInstance2.default, {
  foreignKey: 'elementId1',
  as: 'ElementId1',
  targetKey: 'uuid'
});
NetworkPairing.belongsTo(_elementInstance2.default, {
  foreignKey: 'elementId2',
  as: 'ElementId2',
  targetKey: 'uuid'
});
NetworkPairing.belongsTo(_elementInstance2.default, {
  foreignKey: 'networkElementId1',
  as: 'NetworkElementId1',
  targetKey: 'uuid'
});
NetworkPairing.belongsTo(_elementInstance2.default, {
  foreignKey: 'networkElementId2',
  as: 'NetworkElementId2',
  targetKey: 'uuid'
});
NetworkPairing.belongsTo(_elementInstancePort2.default, {
  foreignKey: 'elemen1PortId',
  as: 'Element1PortId'
});
NetworkPairing.belongsTo(_satellitePort2.default, {
  foreignKey: 'satellitePortId',
  as: 'SatellitePortId'
});

exports.default = NetworkPairing;