'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _dataTracksManager = require('../managers/dataTracksManager');

var _dataTracksManager2 = _interopRequireDefault(_dataTracksManager);

var _appUtils = require('../utils/appUtils');

var _appUtils2 = _interopRequireDefault(_appUtils);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var createDataTrack = function createDataTrack(props, params, callback) {
  _dataTracksManager2.default.create(props.dataTrackObj).then(_appUtils2.default.onCreate.bind(null, params, props.setProperty, 'Unable to create DataTrack object.', callback));
};

var deleteTrackById = function deleteTrackById(props, params, callback) {
  var trackId = _appUtils2.default.getProperty(params, props.trackId);

  _dataTracksManager2.default.deleteByTrackId(trackId).then(_appUtils2.default.onDelete.bind(null, params, 'Was unable to delete Track having Id' + trackId, callback));
};

var findContainerListByInstanceId = function findContainerListByInstanceId(props, params, callback) {
  var instanceId = _appUtils2.default.getProperty(params, props.instanceId);

  _dataTracksManager2.default.findContainerListByInstanceId(instanceId).then(_appUtils2.default.onFind.bind(null, params, props.setProperty, 'Unable to find data tracks', callback));
};

var findContainerListWithStatusByInstanceId = function findContainerListWithStatusByInstanceId(props, params, param, callback) {
  var instanceId = _appUtils2.default.getProperty(params, props.instanceId);

  _dataTracksManager2.default.findContainerListWithStatusByInstanceId(instanceId).then(_appUtils2.default.onFind.bind(null, params, props.setProperty, 'Unable to find docker container list', callback));
};

var getDataTrackById = function getDataTrackById(props, params, callback) {
  var trackId = _appUtils2.default.getProperty(params, props.trackId);
  var errorMsg = '';
  if (props.errorMsg) {
    errorMsg = props.errorMsg;
  }

  _dataTracksManager2.default.findById(trackId).then(_appUtils2.default.onFind.bind(null, params, props.setProperty, errorMsg + 'Unable to find Track having id ' + trackId, callback));
};

var getTrackById = function getTrackById(props, params, callback) {
  var trackId = _appUtils2.default.getProperty(params, props.trackId);

  _dataTracksManager2.default.findById(trackId).then(_appUtils2.default.onFindOptional.bind(null, params, props.setProperty, callback));
};

var getDataTrackByInstanceId = function getDataTrackByInstanceId(props, params, callback) {
  var instanceId = _appUtils2.default.getProperty(params, props.instanceId);

  _dataTracksManager2.default.findByInstanceId(instanceId).then(_appUtils2.default.onFind.bind(null, params, props.setProperty, 'Unable to find Data Track', callback));
};

var getTracksByUserId = function getTracksByUserId(props, params, callback) {
  var userId = _appUtils2.default.getProperty(params, props.userId);

  _dataTracksManager2.default.getTracksByUserId(userId).then(_appUtils2.default.onFind.bind(null, params, props.setProperty, 'Unable to find Data Track', callback));
};

var updateDataTrackById = function updateDataTrackById(props, params, callback) {
  var trackId = _appUtils2.default.getProperty(params, props.trackId);

  _dataTracksManager2.default.updateById(trackId, props.updatedObj).then(_appUtils2.default.onUpdate.bind(null, params, 'Unable to update DataTrack', callback));
};

var updateDataTrackByUserId = function updateDataTrackByUserId(props, params, callback) {
  var userId = _appUtils2.default.getProperty(params, props.userId);

  _dataTracksManager2.default.updateByUserId(userId, props.updatedObj).then(_appUtils2.default.onUpdateOptional.bind(null, params, callback));
};

exports.default = {
  createDataTrack: createDataTrack,
  deleteTrackById: deleteTrackById,
  findContainerListByInstanceId: findContainerListByInstanceId,
  getDataTrackById: getDataTrackById,
  getTrackById: getTrackById,
  getDataTrackByInstanceId: getDataTrackByInstanceId,
  getTracksByUserId: getTracksByUserId,
  updateDataTrackById: updateDataTrackById,
  updateDataTrackByUserId: updateDataTrackByUserId,
  findContainerListWithStatusByInstanceId: findContainerListWithStatusByInstanceId
};