'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _elementManager = require('../managers/elementManager');

var _elementManager2 = _interopRequireDefault(_elementManager);

var _appUtils = require('../utils/appUtils');

var _appUtils2 = _interopRequireDefault(_appUtils);

var _elementImageService = require('./elementImageService');

var _elementImageService2 = _interopRequireDefault(_elementImageService);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var createElement = function createElement(props, params, callback) {
  _elementManager2.default.create(props.element).then(_appUtils2.default.onCreate.bind(null, params, props.setProperty, 'Unable to create Element object.', callback));
};

var deleteElementById = function deleteElementById(props, params, callback) {
  var elementId = _appUtils2.default.getProperty(params, props.elementId);

  _elementManager2.default.deleteElementById(elementId).then(_appUtils2.default.onDelete.bind(null, params, 'Unable to delete Element', callback));
};

var getElementDetails = function getElementDetails(props, params, callback) {
  var elementId = _appUtils2.default.getProperty(params, props.elementId);

  var imageProps = {
    elementId: 'ID',
    setProperty: 'elementImages'
  };

  _elementManager2.default.getElementDetails(elementId).then(_elementImageService2.default.populateImagesForElement.bind(null, imageProps)).then(_appUtils2.default.onFind.bind(null, params, props.setProperty, 'Unable to find Element details', callback));
};

var findElementImageAndRegistryByIdForFogInstance = function findElementImageAndRegistryByIdForFogInstance(props, params, callback) {
  var elementId = _appUtils2.default.getProperty(params, props.elementId);
  var fogId = _appUtils2.default.getProperty(params, props.instanceId);

  _elementManager2.default.findElementImageAndRegistryByIdForFogInstance(elementId, fogId).then(_appUtils2.default.onFind.bind(null, params, props.setProperty, 'Unable to find Element Image or Registry for Element with id ' + elementId + ' and Fog with id ' + fogId, callback));
};

var getElementCatalog = function getElementCatalog(props, params, callback) {
  var userId = _appUtils2.default.getProperty(params, props.userId);

  var imageProps = {
    elementId: 'ID',
    setProperty: 'elementImages'
  };

  _elementManager2.default.getElementCatalog(userId).then(_elementImageService2.default.populateImagesForElements.bind(null, imageProps)).then(_appUtils2.default.onFind.bind(null, params, props.setProperty, 'Error: Element catalog not found', callback));
};

var getElementForPublish = function getElementForPublish(props, params, callback) {
  var userId = _appUtils2.default.getProperty(params, props.userId);

  var imageProps = {
    elementId: 'ID',
    setProperty: 'elementImages'
  };
  _elementManager2.default.getElementForPublish(userId).then(_elementImageService2.default.populateImagesForElements.bind(null, imageProps)).then(_appUtils2.default.onFind.bind(null, params, props.setProperty, 'Error: Element catalog not found', callback));
};

var getNetworkElement = function getNetworkElement(props, params, callback) {
  var networkElementId = _appUtils2.default.getProperty(params, props.networkElementId);

  _elementManager2.default.findElementById(networkElementId).then(_appUtils2.default.onFind.bind(null, params, props.setProperty, 'Unable to find Element object with id ' + networkElementId, callback));
};

var updateElement = function updateElement(props, params, callback) {
  var elementId = _appUtils2.default.getProperty(params, props.elementId);

  _elementManager2.default.updateElementById(elementId, props.updatedElement).then(_appUtils2.default.onUpdate.bind(null, params, 'Unable to update Element object', callback));
};

exports.default = {
  createElement: createElement,
  deleteElementById: deleteElementById,
  findElementImageAndRegistryByIdForFogInstance: findElementImageAndRegistryByIdForFogInstance,
  getElementCatalog: getElementCatalog,
  getElementDetails: getElementDetails,
  getElementForPublish: getElementForPublish,
  getNetworkElement: getNetworkElement,
  updateElement: updateElement
};