'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _fogProvisionKeyManager = require('../managers/fogProvisionKeyManager');

var _fogProvisionKeyManager2 = _interopRequireDefault(_fogProvisionKeyManager);

var _appUtils = require('../utils/appUtils');

var _appUtils2 = _interopRequireDefault(_appUtils);

var _constants = require('../constants.js');

var _constants2 = _interopRequireDefault(_constants);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var checkProvisionKeyExpiry = function checkProvisionKeyExpiry(props, params, callback) {
  var currentTime = new Date(),
      expirationTime = _appUtils2.default.getProperty(params, props.expirationTime);

  if (currentTime < expirationTime) {
    callback(null, params);
  } else {
    callback('error', _constants2.default.MSG.ERROR_PROVISION_KEY_EXPIRED);
  }
};

var createProvisonKeyByInstanceId = function createProvisonKeyByInstanceId(props, params, callback) {
  var instanceId = _appUtils2.default.getProperty(params, props.instanceId),
      newProvision = {
    iofog_uuid: instanceId,
    provisionKey: _appUtils2.default.generateRandomString(8),
    expirationTime: new Date().getTime() + 20 * 60 * 1000
  };

  _fogProvisionKeyManager2.default.createProvisionKey(newProvision).then(_appUtils2.default.onCreate.bind(null, params, props.setProperty, 'Unable to create Provision Key', callback));
};

var deleteProvisonKeyByInstanceId = function deleteProvisonKeyByInstanceId(props, params, callback) {
  var instanceId = _appUtils2.default.getProperty(params, props.instanceId);

  _fogProvisionKeyManager2.default.deleteByInstanceId(instanceId).then(_appUtils2.default.onDeleteOptional.bind(null, params, callback));
};

var deleteByProvisionKey = function deleteByProvisionKey(props, params, callback) {
  var provisionKey = _appUtils2.default.getProperty(params, props.provisionKey);

  _fogProvisionKeyManager2.default.deleteByProvisionKey(provisionKey).then(_appUtils2.default.onDeleteOptional.bind(null, params, callback));
};

var getFogByProvisionKey = function getFogByProvisionKey(props, params, callback) {
  var provisionKey = _appUtils2.default.getProperty(params, props.provisionKey);

  _fogProvisionKeyManager2.default.getByProvisionKey(provisionKey).then(_appUtils2.default.onFind.bind(null, params, props.setProperty, _constants2.default.MSG.ERROR_INVALID_PROVISTION_KEY, callback));
};

var getProvisionKeyByInstanceId = function getProvisionKeyByInstanceId(props, params, callback) {
  var instanceId = _appUtils2.default.getProperty(params, props.instanceId);

  _fogProvisionKeyManager2.default.findByInstanceId(instanceId).then(_appUtils2.default.onFind.bind(null, params, props.setProperty, 'Error: Unable to find provision key with this fog', callback));
};

var deleteExpiredProvisionKeys = function deleteExpiredProvisionKeys(params, callback) {
  //Attempt to delete all of the expired keys.
  var pastTime = new Date().getTime() - 20 * 60;

  _fogProvisionKeyManager2.default.deleteExpiredProvisionKeys(pastTime).then(_appUtils2.default.onDeleteOptional.bind(null, params, callback));
};

exports.default = {
  checkProvisionKeyExpiry: checkProvisionKeyExpiry,
  createProvisonKeyByInstanceId: createProvisonKeyByInstanceId,
  deleteByProvisionKey: deleteByProvisionKey,
  deleteExpiredProvisionKeys: deleteExpiredProvisionKeys,
  deleteProvisonKeyByInstanceId: deleteProvisonKeyByInstanceId,
  getFogByProvisionKey: getFogByProvisionKey,
  getProvisionKeyByInstanceId: getProvisionKeyByInstanceId

};