'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _networkPairingManager = require('../managers/networkPairingManager');

var _networkPairingManager2 = _interopRequireDefault(_networkPairingManager);

var _appUtils = require('../utils/appUtils');

var _appUtils2 = _interopRequireDefault(_appUtils);

var _underscore = require('underscore');

var _underscore2 = _interopRequireDefault(_underscore);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var concatNetwotkElementAndNormalElement = function concatNetwotkElementAndNormalElement(params, callback) {
  params.otherTrackElementIds = params.networkElementId.concat(_underscore2.default.uniq(_underscore2.default.pluck(_underscore2.default.filter(params.otherRoutingList, function (item) {
    return item.is_network_connection !== 1;
  }), 'publishing_element_id')));
  callback(null, params);
};

var concatNetwotkElement2AndNormalElement = function concatNetwotkElement2AndNormalElement(params, callback) {
  params.outputOtherTrackElementId2 = params.networkElementId2.concat(_underscore2.default.uniq(_underscore2.default.pluck(_underscore2.default.filter(params.outputOtherRoutingList, function (item) {
    return item.is_network_connection !== 1;
  }), 'destination_element_id')));
  callback(null, params);
};

var createNetworkPairing = function createNetworkPairing(props, params, callback) {
  var networkPairingObj = {
    instanceId1: _appUtils2.default.getProperty(params, props.instanceId1),
    instanceId2: _appUtils2.default.getProperty(params, props.instanceId2),
    elementId1: _appUtils2.default.getProperty(params, props.elementId1),
    elementId2: _appUtils2.default.getProperty(params, props.elementId2),
    networkElementId1: _appUtils2.default.getProperty(params, props.networkElementId1),
    networkElementId2: _appUtils2.default.getProperty(params, props.networkElementId2),
    isPublicPort: props.isPublic,
    elemen1PortId: _appUtils2.default.getProperty(params, props.elementPortId),
    satellitePortId: _appUtils2.default.getProperty(params, props.satellitePortId)
  };

  _networkPairingManager2.default.create(networkPairingObj).then(_appUtils2.default.onCreate.bind(null, params, props.setProperty, 'Unable to create Network pairing', callback));
};

var deleteNetworkPairing = function deleteNetworkPairing(props, params, callback) {
  var elementId = _appUtils2.default.getProperty(params, props.elementId);

  _networkPairingManager2.default.deleteByElementId(elementId).then(_appUtils2.default.onDeleteOptional.bind(null, params, callback));
};

var deleteNetworkPairingByElementId1 = function deleteNetworkPairingByElementId1(props, params, callback) {
  var elementInstanceData = _appUtils2.default.getProperty(params, props.elementInstanceData);

  _networkPairingManager2.default.deleteByElementId1(_underscore2.default.pluck(elementInstanceData, props.field)).then(_appUtils2.default.onDeleteOptional.bind(null, params, callback));
};

var deleteNetworkPairingById = function deleteNetworkPairingById(props, params, callback) {
  var networkPairingId = _appUtils2.default.getProperty(params, props.networkPairingId);

  _networkPairingManager2.default.deleteById(networkPairingId).then(_appUtils2.default.onDeleteOptional.bind(null, params, callback));
};

var findByElementInstancePortId = function findByElementInstancePortId(props, params, callback) {
  var elementInstancePortData = _appUtils2.default.getProperty(params, props.elementInstancePortData);

  _networkPairingManager2.default.findByElemen1PortIds(_underscore2.default.pluck(elementInstancePortData, props.field)).then(_appUtils2.default.onFindOptional.bind(null, params, props.setProperty, callback));
};

var findOtherTrackByUuids = function findOtherTrackByUuids(params, callback) {
  _networkPairingManager2.default.findNetworkPairingElemenId1ByUuids(_underscore2.default.uniq(_underscore2.default.pluck(_underscore2.default.where(params.otherRoutingList, {
    is_network_connection: 1
  }), 'publishing_element_id'))).then(_appUtils2.default.onFind.bind(null, params, 'networkElementId', 'networkElementId not found.', callback));
};

var findOutputOtherElementInfoByUuids = function findOutputOtherElementInfoByUuids(params, callback) {
  _networkPairingManager2.default.findNetworkPairingElemenId2ByUuids(_underscore2.default.uniq(_underscore2.default.pluck(_underscore2.default.where(params.outputOtherRoutingList, {
    is_network_connection: 1
  }), 'destination_element_id'))).then(_appUtils2.default.onFind.bind(null, params, 'networkElementId2', 'networkElementId2 not found.', callback));
};

var getNetworkPairing = function getNetworkPairing(props, params, callback) {
  var networkPairingId = _appUtils2.default.getProperty(params, props.networkPairingId);

  _networkPairingManager2.default.findById(networkPairingId).then(_appUtils2.default.onFind.bind(null, params, 'networkPairing', 'Cannot find Network Pairing Instance', callback));
};

var getNetworkPairingByFogAndElement = function getNetworkPairingByFogAndElement(props, params, callback) {

  var instanceId1 = _appUtils2.default.getProperty(params, props.instanceId1),
      instanceId2 = _appUtils2.default.getProperty(params, props.instanceId2),
      elementId1 = _appUtils2.default.getProperty(params, props.elementId1),
      elementId2 = _appUtils2.default.getProperty(params, props.elementId2);

  _networkPairingManager2.default.findByFogAndElement(instanceId1, instanceId2, elementId1, elementId2).then(_appUtils2.default.onFind.bind(null, params, props.setProperty, 'Unable to find Network pairing', callback));
};

var findByElementInstanceIds = function findByElementInstanceIds(props, params, callback) {
  var elementInstanceData = _appUtils2.default.getProperty(params, props.elementInstanceData);

  _networkPairingManager2.default.findByElementIds(_underscore2.default.pluck(elementInstanceData, props.field)).then(_appUtils2.default.onFindOptional.bind(null, params, props.setProperty, callback));
};

exports.default = {
  concatNetwotkElementAndNormalElement: concatNetwotkElementAndNormalElement,
  concatNetwotkElement2AndNormalElement: concatNetwotkElement2AndNormalElement,
  createNetworkPairing: createNetworkPairing,
  deleteNetworkPairing: deleteNetworkPairing,
  deleteNetworkPairingById: deleteNetworkPairingById,
  deleteNetworkPairingByElementId1: deleteNetworkPairingByElementId1,
  findByElementInstanceIds: findByElementInstanceIds,
  findByElementInstancePortId: findByElementInstancePortId,
  findOutputOtherElementInfoByUuids: findOutputOtherElementInfoByUuids,
  findOtherTrackByUuids: findOtherTrackByUuids,
  getNetworkPairing: getNetworkPairing,
  getNetworkPairingByFogAndElement: getNetworkPairingByFogAndElement
};