'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _satellitePortManager = require('../managers/satellitePortManager');

var _satellitePortManager2 = _interopRequireDefault(_satellitePortManager);

var _appUtils = require('../utils/appUtils');

var _appUtils2 = _interopRequireDefault(_appUtils);

var _underscore = require('underscore');

var _underscore2 = _interopRequireDefault(_underscore);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var createSatellitePort = function createSatellitePort(props, params, callback) {
  _satellitePortManager2.default.create(props.satellitePortObj).then(_appUtils2.default.onCreate.bind(null, params, props.setProperty, 'Unable to create satellite port', callback));
};

var deletePortsForNetworkElements = function deletePortsForNetworkElements(props, params, callback) {
  var elementId = _appUtils2.default.getProperty(params, props.elementId);

  _satellitePortManager2.default.deletePortsForNetworkElements(elementId).then(_appUtils2.default.onDelete.bind(null, params, 'No Satellite Port found', callback));
};

var deleteSatellitePort = function deleteSatellitePort(props, params, callback) {
  var satellitePortId = _appUtils2.default.getProperty(params, props.satellitePortId);

  _satellitePortManager2.default.deleteById(satellitePortId).then(_appUtils2.default.onDelete.bind(null, params, 'No Satellite Port found', callback));
};

var deleteSatellitePortByIds = function deleteSatellitePortByIds(props, params, callback) {
  var satellitePortIds = _appUtils2.default.getProperty(params, props.satellitePortIds);

  _satellitePortManager2.default.deleteByPortId(_underscore2.default.pluck(satellitePortIds, props.field)).then(_appUtils2.default.onDeleteOptional.bind(null, params, callback));
};

var findBySatellitePortIds = function findBySatellitePortIds(props, params, callback) {
  var networkData = _appUtils2.default.getProperty(params, props.networkData);

  _satellitePortManager2.default.findBySatellitePortIds(_underscore2.default.pluck(networkData, props.field)).then(_appUtils2.default.onFindOptional.bind(null, params, props.setProperty, callback));
};

var getPasscodeForNetworkElements = function getPasscodeForNetworkElements(props, params, callback) {
  var elementId = _appUtils2.default.getProperty(params, props.elementId);

  _satellitePortManager2.default.getPortPasscodeForNetworkElements(elementId).then(_appUtils2.default.onFind.bind(null, params, props.setProperty, 'Cannot find satellite port pass code', callback));
};

var getSatellitePort = function getSatellitePort(props, params, callback) {
  var satellitePortId = _appUtils2.default.getProperty(params, props.satellitePortId);

  _satellitePortManager2.default.findById(satellitePortId).then(_appUtils2.default.onFind.bind(null, params, props.setProperty, 'Cannot find Satellite Port for Network Pairing Instance', callback));
};

exports.default = {
  createSatellitePort: createSatellitePort,
  deletePortsForNetworkElements: deletePortsForNetworkElements,
  deleteSatellitePort: deleteSatellitePort,
  deleteSatellitePortByIds: deleteSatellitePortByIds,
  findBySatellitePortIds: findBySatellitePortIds,
  getPasscodeForNetworkElements: getPasscodeForNetworkElements,
  getSatellitePort: getSatellitePort
};