'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _appUtils = require('./appUtils');

var _appUtils2 = _interopRequireDefault(_appUtils);

var _winstonLogs = require('./winstonLogs');

var _winstonLogs2 = _interopRequireDefault(_winstonLogs);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var fs = require('fs');


var createFile = function createFile(props, params, callback) {

    var fileName = _appUtils2.default.getProperty(params, props.fileName);
    var filePath = props.distDir + '/' + fileName;

    var data = _appUtils2.default.getProperty(params, props.data);

    fs.writeFile(filePath, data, function (err) {
        if (err) {
            callback('error', 'Can\'t write strace data to file');
        } else {
            params[props.setProperty] = filePath;
            callback(null, params);
        }
    });
};

var createDirIfNotExists = function createDirIfNotExists(props, params, callback) {
    var dir = props.distDir;

    if (!fs.existsSync(dir)) {
        fs.mkdirSync(dir);
    }

    callback(null, params);
};

var fileToBase64 = function fileToBase64(props, params, callback) {
    var file = _appUtils2.default.getProperty(params, props.file);
    var bitmap = fs.readFileSync(file);
    params[props.setProperty] = new Buffer(bitmap).toString('base64');
    callback(null, params);
};

var deleteFile = function deleteFile(props, params, callback) {
    var file = _appUtils2.default.getProperty(params, props.file);

    fs.unlink(file, function (err) {
        if (err) {
            _winstonLogs2.default.warn('Error while deleting strace data file. File name: ' + file + ' err: ' + err);
        }
        callback(null, params);
    });
};

exports.default = {
    createFile: createFile,
    createDirIfNotExists: createDirIfNotExists,
    fileToBase64: fileToBase64,
    deleteFile: deleteFile
};